@@ -180,18 +180,7 @@ def add_categorization(
     # Mount router
     app.include_router(router, include_in_schema=include_in_schema)
 
-    # Register scoped docs (svc-infra pattern)
-    try:
-        from svc_infra.api.fastapi.docs.scoped import add_prefixed_docs
-
-        add_prefixed_docs(
-            app,
-            prefix=prefix,
-            title="Transaction Categorization",
-            auto_exclude_from_root=True,
-            visible_envs=None,  # Show in all environments
-        )
-    except ImportError:
-        pass  # svc-infra not available
+    # Scoped docs removed (per architectural decision)
+    # All categorization endpoints appear in main /docs
 
     return engine
