@@ -679,19 +679,7 @@ def add_net_worth_tracking(
     # Mount router
     app.include_router(router, include_in_schema=include_in_schema)
 
-    # Register scoped docs (when svc-infra available)
-    try:
-        from svc_infra.api.fastapi.docs.scoped import add_prefixed_docs
-
-        add_prefixed_docs(
-            app,
-            prefix=prefix,
-            title="Net Worth Tracking",
-            auto_exclude_from_root=True,
-            visible_envs=None,  # Show in all environments
-        )
-    except ImportError:
-        # svc-infra not available, skip scoped docs
-        pass
+    # Scoped docs removed (per architectural decision)
+    # All net worth endpoints appear in main /docs
 
     return tracker
